@@ -1,14 +1,21 @@
-/* Copyright (c) 2009, 2016, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; version 2 of the License.
- 
+ it under the terms of the GNU General Public License, version 2.0,
+ as published by the Free Software Foundation.
+
+ This program is also distributed with certain software (including
+ but not limited to OpenSSL) that is licensed under separate terms,
+ as designated in a particular file or component or in included license
+ documentation.  The authors of MySQL hereby grant you an additional
+ permission to link the program and your derivative works with the
+ separately licensed software that they have included with MySQL.
+
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
+ GNU General Public License, version 2.0, for more details.
+
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
@@ -19,6 +26,7 @@
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
 #define _GNU_SOURCE 1
+/* #undef HAVE_LLVM_LIBCPP */
 #define HAVE_ALLOCA_H 1
 #define HAVE_AIO_H 1
 #define HAVE_ARPA_INET_H 1
@@ -30,7 +38,6 @@
 /* #undef HAVE_CXXABI_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
-#define HAVE_DIRENT_H 1
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
@@ -40,7 +47,6 @@
 #define HAVE_FNMATCH_H 1
 #define HAVE_FPU_CONTROL_H 1
 #define HAVE_GRP_H 1
-#define HAVE_EXPLICIT_TEMPLATE_INSTANTIATION 1
 /* #undef HAVE_IA64INTRIN_H */
 /* #undef HAVE_IEEEFP_H */
 #define HAVE_INTTYPES_H 1
@@ -114,13 +120,14 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
+/* #undef HAVE_LIBRESOLV */
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
 /* Readline */
-/* #undef HAVE_HIST_ENTRY */
-/* #undef USE_LIBEDIT_INTERFACE */
-#define USE_NEW_READLINE_INTERFACE 1
+#define HAVE_HIST_ENTRY 1
+/* #undef USE_NEW_EDITLINE_INTERFACE */
+#define USE_LIBEDIT_INTERFACE 1
 
 #define FIONREAD_IN_SYS_IOCTL 1
 #define GWINSZ_IN_SYS_IOCTL 1
@@ -128,18 +135,17 @@
 /* #undef FIONREAD_IN_SYS_FILIO */
 
 /* Functions we may want to use. */
+/* #undef HAVE_ALIGNED_MALLOC */
+/* #undef HAVE_ALIGNED_FREE */
 /* #undef HAVE_AIOWAIT */
 #define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
-/* #undef HAVE_BFILL */
 /* #undef HAVE_BMOVE */
-#define HAVE_BZERO 1
 #define HAVE_INDEX 1
 #define HAVE_CHOWN 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_CRYPT 1
 #define HAVE_CUSERID 1
-/* #undef HAVE_CXX_NEW */
 /* #undef HAVE_DIRECTIO */
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
@@ -189,13 +195,12 @@
 #define HAVE_LSTAT 1
 #define HAVE_MEMALIGN 1
 /* #define HAVE_MLOCK 1 see Bug#54662 */
-#define HAVE_NPTL 1
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
 #define HAVE_DECL_MADVISE 1
-/* #undef HAVE_DECL_TGOTO */
+#define HAVE_DECL_TGOTO 1
 /* #undef HAVE_DECL_MHA_MAPSIZE_VA */
-#define HAVE_MALLINFO 1
+#define HAVE_MALLOC_INFO 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
 #define HAVE_MKSTEMP 1
@@ -206,12 +211,14 @@
 #define HAVE_POLL 1
 /* #undef HAVE_PORT_CREATE */
 #define HAVE_POSIX_FALLOCATE 1
+#define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
+#define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 /* #undef HAVE_PTHREAD_ATTR_SETPRIO */
 /* #undef HAVE_PTHREAD_ATTR_SETSCHEDPARAM */
@@ -233,7 +240,6 @@
 #define HAVE_PUTENV 1
 #define HAVE_RE_COMP 1
 #define HAVE_REGCOMP 1
-#define HAVE_READDIR_R 1
 #define HAVE_READLINK 1
 #define HAVE_REALPATH 1
 #define HAVE_RENAME 1
@@ -289,9 +295,7 @@
 #define HAVE_TZNAME 1
 #define HAVE_AIO_READ 1
 /* Symbols we may use */
-#define HAVE_SYS_ERRLIST 1
 /* used by stacktrace functions */
-#define HAVE_BSS_START 1
 #define HAVE_BACKTRACE 1
 #define HAVE_BACKTRACE_SYMBOLS 1
 #define HAVE_BACKTRACE_SYMBOLS_FD 1
@@ -308,6 +312,26 @@
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
 #define SPRINTF_RETURNS_INT 1
 
+#define DNS_USE_CPU_CLOCK_FOR_ID 1
+#define HAVE_EPOLL 1
+#define HAVE_EPOLL_CTL 1
+/* #undef HAVE_EVENT_PORTS */
+#define HAVE_INET_NTOP 1
+/* #undef HAVE_KQUEUE */
+/* #undef HAVE_WORKING_KQUEUE */
+#define HAVE_SIGNAL 1
+#define HAVE_TIMERADD 1
+#define HAVE_TIMERCLEAR 1
+#define HAVE_TIMERCMP 1
+#define HAVE_TIMERISSET 1
+
+/* #undef HAVE_DEVPOLL */
+#define HAVE_SIGNAL_H 1
+/* #undef HAVE_SYS_DEVPOLL_H */
+#define HAVE_SYS_EPOLL_H 1
+/* #undef HAVE_SYS_EVENT_H */
+#define HAVE_SYS_QUEUE_H 1
+#define HAVE_TAILQFOREACH 1
 #define USE_MB 1
 #define USE_MB_IDENT 1
 
@@ -382,7 +406,7 @@
 
 #define HAVE_MBSTATE_T
 
-#define MAX_INDEXES 64
+#define MAX_INDEXES 64U
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -400,8 +424,9 @@
 /* #undef WORDS_BIGENDIAN */
 #endif
 
-/* Define to `__inline__' or `__inline' if that's what the C compiler calls
-   it, or to nothing if 'inline' is not supported under any name.  */
+/*
+  Define to `__inline__' or `__inline' if that's what the C compiler calls it.
+*/
 #define C_HAS_inline 1
 #if !(C_HAS_inline)
 #ifndef __cplusplus
@@ -461,7 +486,7 @@
 #define HAVE_LARGE_PAGES 1
 #define HUGETLB_USE_PROC_MEMINFO 1
 /* #undef NO_FCNTL_NONBLOCK */
-#define NO_ALARM 1
+/* #undef NO_ALARM */
 
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
@@ -476,7 +501,7 @@
 #define MACHINE_TYPE "i686"
 /* #undef HAVE_DTRACE */
 
-#define SIGNAL_WITH_VIO_CLOSE 1
+#define SIGNAL_WITH_VIO_SHUTDOWN 1
 
 /* Windows stuff, mostly functions, that have Posix analogs but named differently */
 /* #undef S_IROTH */
@@ -505,8 +530,14 @@
 #define setenv(a,b,c) _putenv_s(a,b)
 #endif
 
-
-
+/*
+   Memcached config options
+*/
+#define WITH_INNODB_MEMCACHED 1
+/* #undef ENABLE_MEMCACHED_SASL */
+/* #undef ENABLE_MEMCACHED_SASL_PWDB */
+#define HAVE_SASL_SASL_H 1
+/* #undef HAVE_HTONLL */
 
 /*
   MySQL features
@@ -516,8 +547,15 @@
 /* #undef EXTRA_DEBUG */
 /* #undef BACKUP_TEST */
 /* #undef CYBOZU */
+#define OPTIMIZER_TRACE 1
 /* #undef USE_SYMDIR */
 
+/*
+   InnoDB config options
+*/
+#define INNODB_COMPILER_HINTS
+#define INNODB_PAGE_ATOMIC_REF_COUNT
+
 /* Character sets and collations */
 #define MYSQL_DEFAULT_CHARSET_NAME "latin1"
 #define MYSQL_DEFAULT_COLLATION_NAME "latin1_swedish_ci"
@@ -570,7 +608,7 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-
+/* #undef COMPILE_FLAG_WERROR */
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -606,16 +644,18 @@
 
 /* #undef SO_EXT */
 
-#define MYSQL_MAJOR_VERSION 5
-#define MYSQL_MINOR_VERSION 5
+#define MYSQL_VERSION_MAJOR 5
+#define MYSQL_VERSION_MINOR 6
+#define MYSQL_VERSION_PATCH 49
+#define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.5.61"
+#define PACKAGE_STRING "MySQL Server 5.6.49"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.5.61"
-#define VERSION "5.5.61"
+#define PACKAGE_VERSION "5.6.49"
+#define VERSION "5.6.49"
 #define PROTOCOL_VERSION 10
 
 
@@ -624,6 +664,12 @@
 #define SIZEOF_TIME_T 4
 /* #undef TIME_T_UNSIGNED */
 
+/* CPU information */
+
+#define CPU_LEVEL1_DCACHE_LINESIZE 64
+
+#define HAVE_LIBNUMA 1
+
 /* For --secure-file-priv */
 #define DEFAULT_SECURE_FILE_PRIV_DIR "/var/lib/mysql-files"
 #define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
